@@ -47,12 +47,16 @@ BEGIN {
 sub defaultValuesInit {
 
     my (
-        $self,                   $cookieName,      $securedCookie,
-        $whatToTrace,            $https,           $port,
-        $customFunctions,        $timeoutActivity, $useRedirectOnError,
-        $useRedirectOnForbidden, $useSafeJail,     $key,
-        $maintenance,            $cda,             $httpOnly,
-        $cookieExpiration,       $cipher,          $args,
+        $self,                    $cookieName,
+        $securedCookie,           $whatToTrace,
+        $https,                   $port,
+        $customFunctions,         $timeoutActivity,
+        $timeoutActivityInterval, $useRedirectOnError,
+        $useRedirectOnForbidden,  $useSafeJail,
+        $key,                     $maintenance,
+        $cda,                     $httpOnly,
+        $cookieExpiration,        $cipher,
+        $args,
     ) = splice @_;
     foreach my $t (qw(https port maintenance)) {
 
@@ -95,6 +99,8 @@ sub defaultValuesInit {
     $httpOnly = defined($httpOnly) ? $httpOnly : $args->{httpOnly};
     $cookieExpiration = $args->{cookieExpiration} || $cookieExpiration;
     $timeoutActivity  = $args->{timeoutActivity}  || $timeoutActivity;
+    $timeoutActivityInterval =
+      $args->{timeoutActivityInterval} || $timeoutActivityInterval;
     $useRedirectOnError =
       defined($useRedirectOnError)
       ? $useRedirectOnError
@@ -119,11 +125,14 @@ sub defaultValuesInit {
     $maintenance = defined($maintenance) ? $maintenance : $args->{maintenance};
 
     return (
-        $cookieName,      $securedCookie,      $whatToTrace,
-        $https,           $port,               $customFunctions,
-        $timeoutActivity, $useRedirectOnError, $useRedirectOnForbidden,
-        $useSafeJail,     $key,                $maintenance,
-        $cda,             $httpOnly,           $cookieExpiration,
+        $cookieName,         $securedCookie,
+        $whatToTrace,        $https,
+        $port,               $customFunctions,
+        $timeoutActivity,    $timeoutActivityInterval,
+        $useRedirectOnError, $useRedirectOnForbidden,
+        $useSafeJail,        $key,
+        $maintenance,        $cda,
+        $httpOnly,           $cookieExpiration,
         $cipher
     );
     1;
