@@ -31,7 +31,7 @@ use constant MAINTENANCE_CODE => 503;
 #inherits Apache::Session
 #link Lemonldap::NG::Common::Apache::Session::SOAP protected globalStorage
 
-our $VERSION = '1.4.9';
+our $VERSION = '1.4.11';
 
 our %EXPORT_TAGS;
 
@@ -48,8 +48,8 @@ our @EXPORT;
 #     locationProtection   locationRegexp         maintenance
 #     port                 refLocalStorage        securedCookie
 #     statusOut            statusPipe             timeoutActivity
-#     useRedirectOnError   useRedirectOnForbidden useSafeJail
-#     whatToTrace
+#     timeoutActivityInterval useRedirectOnError  useRedirectOnForbidden
+#     useSafeJail          whatToTrace
 # );
 #
 # my @nontSharedVar = qw(
@@ -380,7 +380,10 @@ sub retrieveSession {
             'debug' );
 
         # Update the session to notify activity, if necessary
-        if ( $tsv->{timeoutActivity} and ( $now - $datas->{_lastSeen} > 60 ) ) {
+        if ( $tsv->{timeoutActivity}
+            and
+            ( $now - $datas->{_lastSeen} > $tsv->{timeoutActivityInterval} ) )
+        {
             $apacheSession->update( { '_lastSeen' => $now } );
 
             if ( $apacheSession->error ) {
@@ -684,7 +687,7 @@ sub globalInit {
         @$tsv{
             qw( cookieName      securedCookie      whatToTrace
               https           port               customFunctions
-              timeoutActivity useRedirectOnError useRedirectOnForbidden
+              timeoutActivity timeoutActivityInterval useRedirectOnError useRedirectOnForbidden
               useSafeJail     key                maintenance )
         },
         @$ntsv{
@@ -697,7 +700,7 @@ sub globalInit {
         @$tsv{
             qw( cookieName      securedCookie      whatToTrace
               https           port               customFunctions
-              timeoutActivity useRedirectOnError useRedirectOnForbidden
+              timeoutActivity timeoutActivityInterval useRedirectOnError useRedirectOnForbidden
               useSafeJail     key                maintenance )
         },
         @$ntsv{
