@@ -7,10 +7,12 @@ package Lemonldap::NG::Handler::Proxy;
 
 use strict;
 
-use Lemonldap::NG::Handler::Simple qw(:apache :headers :traces);
+use Lemonldap::NG::Handler::Main qw(:apache :headers :tsv);
 use LWP::UserAgent;
+use Lemonldap::NG::Handler::Main::Headers;
+use Lemonldap::NG::Handler::Main::Logger;
 
-our $VERSION = '1.2.2_01';
+our $VERSION = '1.4.9';
 
 ##########################################
 # COMPATIBILITY WITH APACHE AND APACHE 2 #
@@ -35,7 +37,7 @@ sub handler_mp2 : method {
     shift->run(@_);
 }
 
-*lmLog = *Lemonldap::NG::Handler::Simple::lmLog;
+*lmLog = *Lemonldap::NG::Handler::Main::lmLog;
 
 ########
 # MAIN #
@@ -75,7 +77,7 @@ sub run($$) {
         sub {
             return 1 if ( $_[1] =~ /^$/ );
             $request->header(@_) unless ( $_[0] =~ /^(Host|Referer)$/i );
-            $class->lmLog(
+            Lemonldap::NG::Handler::Main::Logger->lmLog(
                 "$class: header pushed to the server: " . $_[0] . ": " . $_[1],
                 'debug'
             );
@@ -148,9 +150,9 @@ sub headers {
                 and $cookieDomain_new
                 and $_[0] =~ /Set-Cookie/i );
 
-            lmSetErrHeaderOut( $r, @_ );
+            Lemonldap::NG::Handler::Main::Headers->lmSetErrHeaderOut( $r, @_ );
 
-            $class->lmLog(
+            Lemonldap::NG::Handler::Main::Logger->lmLog(
                 "$class: header pushed to the client: " . $_[0] . ": " . $_[1],
                 'debug'
             );
@@ -204,10 +206,10 @@ manage redirections if the remote host use it without the good domain.
 =item * B<LmProxyPass (required)>: Real server to push request to
 
 =item * B<LmLocationToReplace> (optional): substitution to do to avoid bad
-redirections. See synopsys for usage.
+redirections. See synopsis for usage.
 
 =item * B<LmCookieDomainToReplace> (optional): substitution to do to set cookies
-from proxied application. See synopsys for usage.
+from proxied application. See synopsis for usage.
 
 =back
 
@@ -222,7 +224,13 @@ L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=back
 
 =head1 BUG REPORT
 
@@ -236,10 +244,25 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005, 2007, 2010 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
+=over
+
+=item Copyright (C) 2007, 2008, 2009, 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2006, 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
